---
title: Event
---

!!! warning
    This API is currently being completely reworked, and is subject to be
    removed in the future when a replacement is introduced

::: pyslurm.deprecated.slurmdb_events
